# mypy-boto3-ssm

Mypy-friendly auto-generated type annotations for `boto3 ssm 1.10.36` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-ssm](#mypy-boto3-ssm)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ssm` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-ssm]

# build service index. You should execute this command everytime
# you update boto3-stubs or install/remove services
python -m python -m mypy_boto3
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import ssm
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_ssm as ssm

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("ssm")
client: ssm.Client = boto3.client("ssm")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ssm.Client = session.client("ssm")


# Paginators need type annotation on creation
describe_activations_paginator: ssm.DescribeActivationsPaginator = client.get_paginator("describe_activations")
describe_association_execution_targets_paginator: ssm.DescribeAssociationExecutionTargetsPaginator = client.get_paginator("describe_association_execution_targets")
describe_association_executions_paginator: ssm.DescribeAssociationExecutionsPaginator = client.get_paginator("describe_association_executions")
describe_automation_executions_paginator: ssm.DescribeAutomationExecutionsPaginator = client.get_paginator("describe_automation_executions")
describe_automation_step_executions_paginator: ssm.DescribeAutomationStepExecutionsPaginator = client.get_paginator("describe_automation_step_executions")
describe_available_patches_paginator: ssm.DescribeAvailablePatchesPaginator = client.get_paginator("describe_available_patches")
describe_effective_instance_associations_paginator: ssm.DescribeEffectiveInstanceAssociationsPaginator = client.get_paginator("describe_effective_instance_associations")
describe_effective_patches_for_patch_baseline_paginator: ssm.DescribeEffectivePatchesForPatchBaselinePaginator = client.get_paginator("describe_effective_patches_for_patch_baseline")
describe_instance_associations_status_paginator: ssm.DescribeInstanceAssociationsStatusPaginator = client.get_paginator("describe_instance_associations_status")
describe_instance_information_paginator: ssm.DescribeInstanceInformationPaginator = client.get_paginator("describe_instance_information")
describe_instance_patch_states_paginator: ssm.DescribeInstancePatchStatesPaginator = client.get_paginator("describe_instance_patch_states")
describe_instance_patch_states_for_patch_group_paginator: ssm.DescribeInstancePatchStatesForPatchGroupPaginator = client.get_paginator("describe_instance_patch_states_for_patch_group")
describe_instance_patches_paginator: ssm.DescribeInstancePatchesPaginator = client.get_paginator("describe_instance_patches")
describe_inventory_deletions_paginator: ssm.DescribeInventoryDeletionsPaginator = client.get_paginator("describe_inventory_deletions")
describe_maintenance_window_execution_task_invocations_paginator: ssm.DescribeMaintenanceWindowExecutionTaskInvocationsPaginator = client.get_paginator("describe_maintenance_window_execution_task_invocations")
describe_maintenance_window_execution_tasks_paginator: ssm.DescribeMaintenanceWindowExecutionTasksPaginator = client.get_paginator("describe_maintenance_window_execution_tasks")
describe_maintenance_window_executions_paginator: ssm.DescribeMaintenanceWindowExecutionsPaginator = client.get_paginator("describe_maintenance_window_executions")
describe_maintenance_window_schedule_paginator: ssm.DescribeMaintenanceWindowSchedulePaginator = client.get_paginator("describe_maintenance_window_schedule")
describe_maintenance_window_targets_paginator: ssm.DescribeMaintenanceWindowTargetsPaginator = client.get_paginator("describe_maintenance_window_targets")
describe_maintenance_window_tasks_paginator: ssm.DescribeMaintenanceWindowTasksPaginator = client.get_paginator("describe_maintenance_window_tasks")
describe_maintenance_windows_paginator: ssm.DescribeMaintenanceWindowsPaginator = client.get_paginator("describe_maintenance_windows")
describe_maintenance_windows_for_target_paginator: ssm.DescribeMaintenanceWindowsForTargetPaginator = client.get_paginator("describe_maintenance_windows_for_target")
describe_parameters_paginator: ssm.DescribeParametersPaginator = client.get_paginator("describe_parameters")
describe_patch_baselines_paginator: ssm.DescribePatchBaselinesPaginator = client.get_paginator("describe_patch_baselines")
describe_patch_groups_paginator: ssm.DescribePatchGroupsPaginator = client.get_paginator("describe_patch_groups")
describe_sessions_paginator: ssm.DescribeSessionsPaginator = client.get_paginator("describe_sessions")
get_inventory_paginator: ssm.GetInventoryPaginator = client.get_paginator("get_inventory")
get_inventory_schema_paginator: ssm.GetInventorySchemaPaginator = client.get_paginator("get_inventory_schema")
get_parameter_history_paginator: ssm.GetParameterHistoryPaginator = client.get_paginator("get_parameter_history")
get_parameters_by_path_paginator: ssm.GetParametersByPathPaginator = client.get_paginator("get_parameters_by_path")
list_association_versions_paginator: ssm.ListAssociationVersionsPaginator = client.get_paginator("list_association_versions")
list_associations_paginator: ssm.ListAssociationsPaginator = client.get_paginator("list_associations")
list_command_invocations_paginator: ssm.ListCommandInvocationsPaginator = client.get_paginator("list_command_invocations")
list_commands_paginator: ssm.ListCommandsPaginator = client.get_paginator("list_commands")
list_compliance_items_paginator: ssm.ListComplianceItemsPaginator = client.get_paginator("list_compliance_items")
list_compliance_summaries_paginator: ssm.ListComplianceSummariesPaginator = client.get_paginator("list_compliance_summaries")
list_document_versions_paginator: ssm.ListDocumentVersionsPaginator = client.get_paginator("list_document_versions")
list_documents_paginator: ssm.ListDocumentsPaginator = client.get_paginator("list_documents")
list_resource_compliance_summaries_paginator: ssm.ListResourceComplianceSummariesPaginator = client.get_paginator("list_resource_compliance_summaries")
list_resource_data_sync_paginator: ssm.ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.

## Submodules

- `master` - Install `mypy-boto3` package.